# encoding: utf8

from setuptools import setup


setup(
    author='Eitan Joseph, Chami Lamelas',
    author_email="eitanjoseph@brandeis.edu",
    description='A data structures and algorithms library based on Introduction to Algorithms Third Edition by Thomas H. Cormen.',
    install_requires=['dalpy'],
    long_description='''Use `DALPy <https://pypi.org/project/dalpy/>`_ instead.''',
    maintainer='UNKNOWN',
    maintainer_email="UNKNOWN\nblas_opt_info:\nblas_mkl_info:\n  FOUND:\n    libraries = ['mkl_intel_lp64', 'mkl_intel_thread', 'mkl_core', 'iomp5', 'pthread']\n    library_dirs = ['/Users/filo/anaconda/lib']\n    define_macros = [('SCIPY_MKL_H', None)]\n    include_dirs = ['/Users/filo/anaconda/include']\n\n  FOUND:\n    libraries = ['mkl_intel_lp64', 'mkl_intel_thread', 'mkl_core', 'iomp5', 'pthread']\n    library_dirs = ['/Users/filo/anaconda/lib']\n    define_macros = [('SCIPY_MKL_H', None)]\n    include_dirs = ['/Users/filo/anaconda/include']\n\nUNKNOWN",
    name='cormen-lib',
    platforms=['all'],
    py_modules=['wheel-platform-tag-is-broken-on-empty-wheels-see-issue-141'],
    url='https://pypi.org/project/dalpy/',
    version="1.1.1",
    zip_safe=False,
)
